diff --git a/django/core/management/commands/dbshell.py b/django/core/management/commands/dbshell.py
index 1cb6b52f04..6782ef48f3 100644
--- a/django/core/management/commands/dbshell.py
+++ b/django/core/management/commands/dbshell.py
@@ -20,11 +20,11 @@ class Command(BaseCommand):
         connection = connections[options['database']]
         try:
             connection.client.runshell()
-        except OSError:
-            # Note that we're assuming OSError means that the client program
-            # isn't installed. There's a possibility OSError would be raised
-            # for some other reason, in which case this error message would be
-            # inaccurate. Still, this message catches the common case.
+        except FileNotFoundError:
+            # Note that we're assuming the FileNotFoundError relates to the
+            # command missing. It could be raised for some other reason, in
+            # which case this error message would be inaccurate. Still, this
+            # message catches the common case.
             raise CommandError(
                 'You appear not to have the %r program installed or on your path.' %
                 connection.client.executable_name